import { _load } from '../../util/loader.js';
import { timerify } from '../../util/performance.js';
import { hasDependency } from '../../util/plugin.js';
import { fallback } from './fallback.js';
import { getDependenciesDeep } from './helpers.js';
export const NAME = 'ESLint';
export const ENABLERS = ['eslint'];
export const isEnabled = ({ dependencies }) => hasDependency(dependencies, ENABLERS);
export const CONFIG_FILE_PATTERNS = ['.eslintrc', '.eslintrc.{js,json,cjs}', '.eslintrc.{yml,yaml}', 'package.json'];
export const ENTRY_FILE_PATTERNS = ['eslint.config.js'];
const findESLintDependencies = async (configFilePath, { cwd, manifest }) => {
    let config = undefined;
    try {
        config = configFilePath.endsWith('package.json') ? manifest.eslintConfig : await _load(configFilePath);
    }
    catch (error) {
        if (error instanceof Error && error.cause instanceof Error && /Failed to patch ESLint/.test(error.cause.message)) {
            return fallback(configFilePath, { cwd });
        }
        else {
            throw error;
        }
    }
    if (!config)
        return [];
    const dependencies = await getDependenciesDeep(configFilePath);
    return Array.from(dependencies);
};
export const findDependencies = timerify(findESLintDependencies);
